<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <location filename="../src/policykitagent.cpp" line="169"/>
        <source>PolicyKit Information</source>
        <translation>Informações PolicyKit</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>Já está em curso uma autenticação. Por favor tente mais tarde.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization Failed</source>
        <translation>Falha de autorização</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization failed for some reason</source>
        <translation>Autorização falhou por algum motivo</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="162"/>
        <source>PolicyKit Error</source>
        <translation>Erro PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Requer autenticação</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identidade:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Palavra-passe:</translation>
    </message>
</context>
</TS>
